/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.sharing;

import java.util.Collection;
import java.util.Iterator;
import java.util.List;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;
import com.openexchange.exception.OXException;
import com.openexchange.file.storage.DefaultFileStorageObjectPermission;
import com.openexchange.file.storage.FileStorageObjectPermission;
import com.openexchange.guard.osgi.Services;
import com.openexchange.session.Session;
import com.openexchange.user.User;
import com.openexchange.user.UserService;

/**
 * {@link SharingUtil}
 *
 * @author <a href="mailto:greg.hill@open-xchange.com">Greg Hill</a>
 * @since v2.10.0
 */
public class SharingUtil {

    /**
     * Get user IDs of shares within the same context
     * @param list
     * @return
     * @throws JSONException
     */
    public static JSONArray getIDs (List<FileStorageObjectPermission> list) throws JSONException {
        JSONArray items = new JSONArray();
        if (!list.isEmpty()) {
            for (FileStorageObjectPermission pem : list) {
                JSONObject user = new JSONObject();
                user.put("id", pem.getEntity());
                items.put(user);
            }
        }
        return items;
    }

    public static JSONArray getIDs(Collection list) throws JSONException {
        Iterator items = list.iterator();
        JSONArray users = new JSONArray();
        while (items.hasNext()) {
            DefaultFileStorageObjectPermission share = (DefaultFileStorageObjectPermission) items.next();
            JSONObject user = new JSONObject();
            user.put("id", share.getEntity());
            users.put(user);
        }
        return users;
    }

    private static void addUser(JSONArray items, User shareUser) throws JSONException {
        final String mail = shareUser.getMail();
        if (mail != null && !mail.isEmpty()) {
            JSONObject user = new JSONObject();
            user.put("email", mail);
            items.put(user);
        }
    }

    public static JSONArray getEmails(Session session, List<FileStorageObjectPermission> list, int createdBy) throws OXException, JSONException {
        JSONArray items = new JSONArray();
        if (!list.isEmpty()) {
            UserService userService = Services.getService(UserService.class);
            for (FileStorageObjectPermission pem : list) {
                User shareUser = userService.getUser(pem.getEntity(), session.getContextId());
                addUser(items, shareUser);
            }
            if (session.getUserId() != createdBy) {  // Bug GUARD-203, if shared file, original owner keys not added
                User owner = userService.getUser(createdBy, session.getContextId());
                addUser(items, owner);
            }
        }
        return items;
    }


}
